django-dashing — django-dashing 0.2 documentation

### Navigation

- index
- next |
- django-dashing 0.2 documentation »

# django-dashing

django-dashing is a customisable, modular dashboard application framework for Django to visualize interesting data about your project. Inspired in the exceptionally handsome dashboard framework Dashing

## Prerequisites

- Django 1.5.+

## Key concepts

- Use premade widgets, or fully create your own with css, html, and javascript.
- Use the API to push data to your dashboards.
- Drag & Drop interface for re-arranging your widgets.

## Topics

General guides to using Django Dashing.

- 1. Getting Started
  - 1.1. Installation
  - 1.2. Django Settings
  - 1.3. Config File
  - 1.4. Template File
  - 1.5. Python Widget Classes
- 2. Dashboards
  - 2.1. Single Dashboard
  - 2.2. Multiple Dashboards
- 3. Widgets
  - 3.1. Clock Widget
  - 3.2. Graph Widget
  - 3.3. List Widget
  - 3.4. Number Widget
  - 3.5. Knob Widget
  - 3.6. Map Widget
- 4. Custom Widgets
  - 4.1. Static Files
  - 4.2. Python Class
  - 4.3. Distribution

### Navigation

- index
- next |
- django-dashing 0.2 documentation »